KNeighborsRegressor — hubness 0.21a1 documentation

# KNeighborsRegressor

class `hubness.neighbors.` `KNeighborsRegressor`(n_neighbors=5, weights='uniform', algorithm: str = 'auto', algorithm_params: dict = None, hubness: str = None, hubness_params: dict = None, leaf_size=30, p=2, metric='minkowski', metric_params=None, n_jobs=None, **kwargs)

  Bases: `hubness.neighbors.base.NeighborsBase`, `hubness.neighbors.base.KNeighborsMixin`, `sklearn.neighbors.base.SupervisedFloatMixin`, `sklearn.base.RegressorMixin`

  Regression based on k-nearest neighbors.

  The target is predicted by local interpolation of the targets associated of the nearest neighbors in the training set.

  Read more in the User Guide.

  Parameters

    - n_neighbors (int, optional (default = 5)) – Number of neighbors to use by default for `kneighbors()` queries.

    - weights (str or callable) –

      weight function used in prediction. Possible values:

      - ’uniform’ : uniform weights. All points in each neighborhood are weighted equally.

      - ’distance’ : weight points by the inverse of their distance. in this case, closer neighbors of a query point will have a greater influence than neighbors which are further away.

      - [callable] : a user-defined function which accepts an array of distances, and returns an array of the same shape containing the weights.

      Uniform weights are used by default.

    - algorithm ({'auto', 'hnsw', 'lsh', 'ball_tree', 'kd_tree', 'brute'}, optional) –

      Algorithm used to compute the nearest neighbors:

      - ’hnsw’ will use `HNSW`

      - ’lsh’ will use `LSH`

      - ’ball_tree’ will use `BallTree`

      - ’kd_tree’ will use `KDTree`

      - ’brute’ will use a brute-force search.

      - ’auto’ will attempt to decide the most appropriate algorithm based on the values passed to `fit()` method.

      Note: fitting on sparse input will override the setting of this parameter, using brute force.

    - algorithm_params (dict, optional) – Override default parameters of the NN algorithm. For example, with algorithm=’lsh’ and algorithm_params={n_candidates: 100} one hundred approximate neighbors are retrieved with LSH. If parameter hubness is set, the candidate neighbors are further reordered with hubness reduction. Finally, n_neighbors objects are used from the (optionally reordered) candidates.

    - TODO add all supported hubness reduction methods (#) –

    - hubness ({'mutual_proximity', 'local_scaling', 'dis_sim_local', None}, optional) – Hubness reduction algorithm - ‘mutual_proximity’ or ‘mp’ will use `MutualProximity' - 'local_scaling' or 'ls' will use :class:`LocalScaling` - ‘dis_sim_local’ or ‘dsl’ will use `DisSimLocal` If None, no hubness reduction will be performed (=vanilla kNN).

    - hubness_params (dict, optional) – Override default parameters of the selected hubness reduction algorithm. For example, with hubness=’mp’ and hubness_params={‘method’: ‘normal’} a mutual proximity variant is used, which models distance distributions with independent Gaussians.

    - leaf_size (int, optional (default = 30)) – Leaf size passed to BallTree or KDTree. This can affect the speed of the construction and query, as well as the memory required to store the tree. The optimal value depends on the nature of the problem.

    - p (integer, optional (default = 2)) – Power parameter for the Minkowski metric. When p = 1, this is equivalent to using manhattan_distance (l1), and euclidean_distance (l2) for p = 2. For arbitrary p, minkowski_distance (l_p) is used.

    - metric (string or callable, default 'minkowski') – the distance metric to use for the tree. The default metric is minkowski, and with p=2 is equivalent to the standard Euclidean metric. See the documentation of the DistanceMetric class for a list of available metrics.

    - metric_params (dict, optional (default = None)) – Additional keyword arguments for the metric function.

    - n_jobs (int or None, optional (default=None)) – The number of parallel jobs to run for neighbors search. `None` means 1 unless in a `joblib.parallel_backend` context. `-1` means using all processors. See Glossary for more details. Doesn’t affect `fit()` method.

  Examples

      >>> X = [[0], [1], [2], [3]]
      >>> y = [0, 0, 1, 1]
      >>> from hubness.neighbors import KNeighborsRegressor
      >>> neigh = KNeighborsRegressor(n_neighbors=2)
      >>> neigh.fit(X, y) # doctest: +ELLIPSIS
      KNeighborsRegressor(...)
      >>> print(neigh.predict([[1.5]]))
      [0.5]

  See also

  `NearestNeighbors`, `RadiusNeighborsRegressor`, `KNeighborsClassifier`, `RadiusNeighborsClassifier`

  Notes

  See Nearest Neighbors in the online documentation for a discussion of the choice of `algorithm` and `leaf_size`.

  Warning

  Regarding the Nearest Neighbors algorithms, if it is found that two neighbors, neighbor k+1 and k, have identical distances but different labels, the results will depend on the ordering of the training data.

  https://en.wikipedia.org/wiki/K-nearest_neighbor_algorithm

  Methods Summary

  `predict`(X) | Predict the target for the provided data

  Methods Documentation

  `predict`(X)

    Predict the target for the provided data

    Parameters

      X (array-like, shape (n_query, n_features), or (n_query, n_indexed) if metric == 'precomputed') – Test samples.

    Returns

      y – Target values

    Return type

      array of int, shape = [n_samples] or [n_samples, n_outputs]